@@ -50,6 +50,7 @@ def update():
     CSupdate = 0
     CS2update = 0
     BSupdate = 0
+    HUupdate = 0
     rec10d.rec10db.set_new_status("8")
     for datum in rec10d.rec10db.select_get_update_epg_ch("6"):
         bctype = datum[0]
@@ -65,6 +66,10 @@ def update():
             if BSupdate == 0:
                 ret.append(u"bs")
                 BSupdate = 1
+        elif bctype == "hu" or bctype == u"hu":
+            if HUupdate == 0:
+                ret.append(u"hu")
+                HUupdate = 1
         else:
             ret.append(bctype)
     return ret
\ No newline at end of file
