@@ -21,6 +21,7 @@ if __name__ == "__main__":
     parser=optparse.OptionParser(usage=usage,version=version)
     parser.add_option("-s","--search",action="store",type="string",dest="ltitle",default="",metavar="TITLE",help="test to search where the title should be contained(test for -e)")
     parser.add_option("-A","--Auto",action="store_true",dest="auto",default=False,help="auto classifying mode(not a test)")
+    parser.add_option("-D","--Delete",action="store_true",dest="delete",default=False,help="auto delete tempfile mode(not a test)")
     parser.add_option("-e","--exec",action="store",type="string",dest="etitle",default="",metavar="TITLE",help="exec move(not a test)")
     parser.add_option("-l","--list",action="store_true",dest="list",default=False,help="File listing mode(test for -A)")
     parser.add_option("-t","--tssearch",action="store_true",dest="tssearch",default=False,help="Ts move auto search")
@@ -33,45 +34,52 @@ if __name__ == "__main__":
         ltitle=unicode(opts.ltitle,'utf-8')
         sf=guess.searchFolder(ltitle, recordedpath)
         print "###MKV###"
-        recdblist.printutf8(os.path.join(sf, auto_move.get_move_dest_path(ltitle,recpath,sf,".mkv")+".mkv"))
+        recdblist.printutf8(os.path.join(sf, auto_move.get_move_dest_path(ltitle,recpath,sf,".mkv")+".mkv"),verbose_level=100)
         print "\n"
         print "###MP4###"
-        recdblist.printutf8(os.path.join(sf, auto_move.get_move_dest_path(ltitle,recpath,sf,".mp4")+".mp4"))
+        recdblist.printutf8(os.path.join(sf, auto_move.get_move_dest_path(ltitle,recpath,sf,".mp4")+".mp4"),verbose_level=100)
         print "\n"
     elif opts.auto:##-A の場合
         sa=auto_move.search_file(recpath, recordedpath, ".mkv")
         for t in sa:
-            recdblist.printutf8(u"自動推測実行中-MKV")
+            recdblist.printutf8(u"自動推測実行中-MKV",verbose_level=100)
             sf=guess.searchFolder(t,recordedpath)
             if sf!="":
-                recdblist.printutf8(u"移動先")
-                recdblist.printutf8(t+" : "+os.path.join(sf, auto_move.get_move_dest_path(t, recpath,sf,".mkv")+".mkv"))
-                recdblist.printutf8(u"実行中")
+                recdblist.printutf8(u"移動先",verbose_level=100)
+                recdblist.printutf8(t+" : "+os.path.join(sf, auto_move.get_move_dest_path(t, recpath,sf,".mkv")+".mkv"),verbose_level=100)
+                recdblist.printutf8(u"実行中",verbose_level=100)
                 auto_move.execMove(t, recpath, recordedpath,".mkv",1)
             else:
-                recdblist.printutf8(t+" can't find matching folder")
+                recdblist.printutf8(t+" can't find matching folder",verbose_level=100)
         sa=auto_move.search_file(recpath, recordedpath, ".mp4")
         for t in sa:
-            recdblist.printutf8(u"自動推測実行中-MP4")
+            recdblist.printutf8(u"自動推測実行中-MP4",verbose_level=100)
             sf=guess.searchFolder(t,recordedpath)
             if sf!="":
-                recdblist.printutf8(u"移動先")
-                recdblist.printutf8(t+" : "+os.path.join(sf, auto_move.get_move_dest_path(t, recpath,sf,".mp4")+".mp4"))
-                recdblist.printutf8(u"実行中")
+                recdblist.printutf8(u"移動先",verbose_level=100)
+                recdblist.printutf8(t+" : "+os.path.join(sf, auto_move.get_move_dest_path(t, recpath,sf,".mp4")+".mp4"),verbose_level=100)
+                recdblist.printutf8(u"実行中",verbose_level=100)
                 auto_move.execMove(t, recpath, recordedpath,".mp4",1)
             else:
-                recdblist.printutf8(t+" can't find matching folder")
+                recdblist.printutf8(t+" can't find matching folder",verbose_level=100)
+    elif opts.delete:##-Dの場合
+        sa=auto_move.search_file(recpath, recordedpath,".mkv")
+        for t in sa:
+            auto_move.execDelete(t, recpath)
+        sa=auto_move.search_file(recpath, recordedpath,".mp4")
+        for t in sa:
+            auto_move.execDelete(t, recpath)
     elif opts.list:##-lの場合
         sa=auto_move.search_file(recpath, recordedpath,".mkv")
         for t in sa:
             sf=guess.searchFolder(t,recordedpath)
             if sf!="":
-                recdblist.printutf8(t+u" : "+os.path.join(sf, auto_move.get_move_dest_path(t, recpath,sf,".mkv")+".mkv"))
+                recdblist.printutf8(t+u" : "+os.path.join(sf, auto_move.get_move_dest_path(t, recpath,sf,".mkv")+".mkv"),verbose_level=100)
         sa=auto_move.search_file(recpath, recordedpath,".mp4")
         for t in sa:
             sf=guess.searchFolder(t,recordedpath)
             if sf!="":
-                recdblist.printutf8(t+u" : "+os.path.join(sf, auto_move.get_move_dest_path(t, recpath,sf,".mp4")+".mp4"))
+                recdblist.printutf8(t+u" : "+os.path.join(sf, auto_move.get_move_dest_path(t, recpath,sf,".mp4")+".mp4"),verbose_level=100)
     elif opts.etitle!="":
         if os.path.exists(os.path.join(recpath, etitle+".mkv")):
             auto_move.execMove(etitle,recpath, recordedpath,".mkv",1)
@@ -92,7 +100,7 @@ if __name__ == "__main__":
                     print "\n"
             sa=auto_move.search_file(recpath, tsmovepath,".ts")
         else:
-            recdblist.printutf8(u"ts_movepathが設定されていません。/etc/rec10.confを設定してください。")
+            recdblist.printutf8(u"ts_movepathが設定されていません。/etc/rec10.confを設定してください。",verbose_level=100)
     elif opts.tsmove:##-Tの場合
         tsmovepath=""
         try:
@@ -104,13 +112,13 @@ if __name__ == "__main__":
             for t in sa:
                 sf=guess.searchFolder(t,tsmovepath,700)
                 if sf!="":
-                    recdblist.printutf8(u"移動先")
-                    recdblist.printutf8(t+" : "+os.path.join(sf, auto_move.get_move_dest_path(t, recpath,sf,".ts")+".ts"))
-                    recdblist.printutf8(u"実行中")
+                    recdblist.printutf8(u"移動先",verbose_level=100)
+                    recdblist.printutf8(t+" : "+os.path.join(sf, auto_move.get_move_dest_path(t, recpath,sf,".ts")+".ts"),verbose_level=100)
+                    recdblist.printutf8(u"実行中",verbose_level=100)
                     auto_move.execMove(t, recpath, tsmovepath,".ts",0)
             sa=auto_move.search_file(recpath, tsmovepath,".ts")
         else:
-            recdblist.printutf8(u"ts_movepathが設定されていません。/etc/rec10.confを設定してください。")
+            recdblist.printutf8(u"ts_movepathが設定されていません。/etc/rec10.confを設定してください。",verbose_level=100)
     elif opts.seriespath!="":##-Sの場合##与えられたパスにシリーズがそろっているかを調べる。
         ss=guess.detSeriesNum(opts.seriespath)
         for sstitle, ssv in ss.iteritems():
