@@ -1150,4 +1150,10 @@ class DB_MySQL:
         self.drop_in_settings()
         self.new_in_settings()
         self.close_db(db)
-        self.change_version_in_status("96")
\ No newline at end of file
+        self.change_version_in_status("96")
+    def update_db_96to98(self):
+        db = self.connect_db()
+        self.drop_in_settings()
+        self.new_in_settings()
+        self.close_db(db)
+        self.change_version_in_status("98")
\ No newline at end of file
