@@ -26,10 +26,12 @@ def write_time(pout, ch ,times):
     """
     指定された時間分tsを取得してepgの入ったxmlとして書き出す
     """
-    recdblist.Commonlogex(u"通常","write_time(ts2epg.py)",u"Ts-EPG XML書き出し処理開始" ,u"CH:"+ch)
+    recdblist.Commonlogex(u"通常","write_time(ts2epg.py)",u"Ts-EPG XML書き出し処理開始" ,u"CH:"+ch,log_level=500)
     timet = times
     if re.search(u'CS', ch):
         mode = "/CS"
+    elif re.search(u'tehu', chdb.chsearch(ch)['bctype']):
+        mode = "/HU"
     elif len(ch)>2:
         mode = "/BS"
     else:
@@ -41,7 +43,7 @@ def write_time(pout, ch ,times):
     tv2ts.tv2tsmix(pout + ".ts", ch, timet)
     exe = "export LANG=ja_JP.UTF-8 && nice -n 15 " + epgdump + " " + mode + " " + pout + ".ts " + pout
     recdblist.printutf8(exe)
-    recdblist.Commonlogex(u"通常", "write_time(ts2epg.py)", exe,"")
+    recdblist.Commonlogex(u"通常", "write_time(ts2epg.py)", exe,"",log_level=500)
     os.system(exe)
     time.sleep(10)
 
