@@ -6,6 +6,7 @@
 import xml.dom.minidom
 import datetime
 import re
+import traceback
 
 import zenhan
 import chdb
@@ -129,6 +130,6 @@ def addTitle_Subtitle(recompiled,num,title,exp):
         else:
             newtitle=title
     except Exception, inst:
-        recdblist.Commonlogex("Error", "addTitle_Subtitle(xml2db_dob.py)", str(type(inst)),str(inst))
+        recdblist.Commonlogex("Error", "addTitle_Subtitle(xml2db_dob.py)", str(type(inst)),str(inst)+traceback.format_exc(),log_level=200)
         newtitle=title
     return newtitle
\ No newline at end of file
